OptionalTlsAcceptor

Trait OptionalTlsAcceptor 

pub trait OptionalTlsAcceptor { }
Trait that is implemented over NoSslAcceptor and SslAcceptor that serves as a generic bound to make a struct with. Used in the Server to specify impls based on whether the server is running over SSL or not.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl OptionalTlsAcceptor for TlsAcceptor

Available on crate features async-ssl or sync-ssl only.

Implementors