Trait websocket::stream::sync::AsTcpStream
[−]
[src]
pub trait AsTcpStream {
fn as_tcp(&self) -> &TcpStream;
}The ability access a borrow to an underlying TcpStream,
so one can set options on the stream such as nonblocking.
Required Methods
Implementations on Foreign Types
impl<T> AsTcpStream for Box<T> where
T: AsTcpStream, [src]
T: AsTcpStream,