Struct websocket::sender::Sender [] [src]

pub struct Sender<W> { /* fields omitted */ }

A Sender that wraps a Writer and provides a default implementation using DataFrames and Messages.

Methods

impl<W> Sender<W>
[src]

[src]

Create a new WebSocketSender using the specified Writer.

[src]

Returns a reference to the underlying Writer.

[src]

Returns a mutable reference to the underlying Writer.

impl Sender<WebSocketStream>
[src]

[src]

Closes the sender side of the connection, will cause all pending and future IO to return immediately with an appropriate value.

[src]

Shuts down both Sender and Receiver, will cause all pending and future IO to return immediately with an appropriate value.

[src]

Changes whether the sender is in nonblocking mode.