pub trait AsTcpStream {
// Required method
fn as_tcp(&self) -> &TcpStream ⓘ;
}Expand description
The ability access a borrow to an underlying TcpStream,
so one can set options on the stream such as nonblocking.
Required Methods
Implementations on Foreign Types
Sourceimpl<T> AsTcpStream for Box<T>where
T: AsTcpStream + ?Sized,
impl<T> AsTcpStream for Box<T>where
T: AsTcpStream + ?Sized,
Implementors
impl AsTcpStream for TcpStream
impl AsTcpStream for TlsStream<TcpStream>
Available on crate feature
sync-ssl only.